@@ -182,6 +182,7 @@ def transform():
 @click.option('--output-s3', help='Output path on S3', type=str, default=None, required=True)
 @click.option('--input-type', help='Input MIME type ("Content-Type" header)', type=str, default=None, required=True)
 @click.option('--output-type', help='Output MIME type ("Accept" header)', type=str, default=None, required=True)
+@click.option('--output-json', help='Save job information in JSON file', type=str, default=None)
 @click.option('--instance-type', help='SageMaker Instance type (e.g., ml.m5.large)', type=str, default="ml.m5.large")
 @click.option('--instance-count', help='Number of containers to use (processing will be distributed)', type=int, default=1)
 @click.option('--payload-mb', help='Maximum payload size (MB)', type=int, default=32)
@@ -198,7 +199,8 @@ def transform_create_cli(
         output_type,
         instance_type,
         instance_count,
-        payload_mb):
+        payload_mb,
+        output_json):
     """
     Create a batch transformation job for objects in S3
 
@@ -222,6 +224,7 @@ def transform_create_cli(
         output_type=output_type,
         instance_type=instance_type,
         instance_count=instance_count,
+        output_json=output_json,
         payload_mb=payload_mb
     )
 
@@ -457,11 +460,12 @@ def endpoint_describe_cli(name, field):
 @click.option('--model', type=str, default=None)
 @click.option('--variant', type=str, default=None)
 @click.option('--input', type=str, default=None)
+@click.option('--input-glob', type=str, default=None, help='glob pattern if input is directory (e.g., `**/*.wav`)')
 @click.option('--output', type=str, default=None)
 @click.option('--input-type', type=str, default=None)
 @click.option('--output-type', type=str, default=None)
 @click.option('--model-dir', type=str, default=None)
-def endpoint_invoke_cli(name, model, variant, input, output, input_type, output_type, model_dir):
+def endpoint_invoke_cli(name, model, variant, input, input_glob, output, input_type, output_type, model_dir):
     """
     Invoke a SageMaker endpoint or a SageMaker-style model in a local directory
     """
@@ -472,6 +476,7 @@ def endpoint_invoke_cli(name, model, variant, input, output, input_type, output_
         model=cli_argument(model, session=session),
         variant=variant,
         input=input,
+        input_glob=input_glob,
         output=output,
         input_type=input_type,
         output_type=output_type,
